==> huaweicloudsdkprojectman-3.1.79-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/list_project_domains_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListProjectDomainsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'domains': 'list[CreateProjectDomainResponseBody]'
    }

    attribute_map = {
        'total': 'total',
        'domains': 'domains'
    }

    def __init__(self, total=None, domains=None):
        """ListProjectDomainsResponse

        The model defined in huaweicloud sdk

        :param total: 领域总数
        :type total: int
        :param domains: 领域列表
        :type domains: list[:class:`huaweicloudsdkprojectman.v4.CreateProjectDomainResponseBody`]
        """
        
        super(ListProjectDomainsResponse, self).__init__()

        self._total = None
        self._domains = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if domains is not None:
            self.domains = domains

    @property
    def total(self):
        """Gets the total of this ListProjectDomainsResponse.

        领域总数

        :return: The total of this ListProjectDomainsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListProjectDomainsResponse.

        领域总数

        :param total: The total of this ListProjectDomainsResponse.
        :type total: int
        """
        self._total = total

    @property
    def domains(self):
        """Gets the domains of this ListProjectDomainsResponse.

        领域列表

        :return: The domains of this ListProjectDomainsResponse.
        :rtype: list[:class:`huaweicloudsdkprojectman.v4.CreateProjectDomainResponseBody`]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        """Sets the domains of this ListProjectDomainsResponse.

        领域列表

        :param domains: The domains of this ListProjectDomainsResponse.
        :type domains: list[:class:`huaweicloudsdkprojectman.v4.CreateProjectDomainResponseBody`]
        """
        self._domains = domains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListProjectDomainsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.1.145-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/list_project_domains_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListProjectDomainsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'domains': 'list[CreateProjectDomainResponseBody]'
    }

    attribute_map = {
        'total': 'total',
        'domains': 'domains'
    }

    def __init__(self, total=None, domains=None):
        r"""ListProjectDomainsResponse

        The model defined in huaweicloud sdk

        :param total: 领域总数
        :type total: int
        :param domains: 领域列表
        :type domains: list[:class:`huaweicloudsdkprojectman.v4.CreateProjectDomainResponseBody`]
        """
        
        super(ListProjectDomainsResponse, self).__init__()

        self._total = None
        self._domains = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if domains is not None:
            self.domains = domains

    @property
    def total(self):
        r"""Gets the total of this ListProjectDomainsResponse.

        领域总数

        :return: The total of this ListProjectDomainsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListProjectDomainsResponse.

        领域总数

        :param total: The total of this ListProjectDomainsResponse.
        :type total: int
        """
        self._total = total

    @property
    def domains(self):
        r"""Gets the domains of this ListProjectDomainsResponse.

        领域列表

        :return: The domains of this ListProjectDomainsResponse.
        :rtype: list[:class:`huaweicloudsdkprojectman.v4.CreateProjectDomainResponseBody`]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        r"""Sets the domains of this ListProjectDomainsResponse.

        领域列表

        :param domains: The domains of this ListProjectDomainsResponse.
        :type domains: list[:class:`huaweicloudsdkprojectman.v4.CreateProjectDomainResponseBody`]
        """
        self._domains = domains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListProjectDomainsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
